@@ -1,6 +1,6 @@
 import os
 
-from unittest import TestCase
+from unittest import TestCase, mock
 
 from pipeline import Pipeline, Message, PipelineError
 
@@ -22,6 +22,17 @@ class TestPipeline(TestCase):
         destination.write(Message({"key": "dummy", "test": "value"}))
         self.assertEqual(len(destination.results), 1)
 
+    @mock.patch("redis.Redis")
+    def test_pipeline_redis(self, r):
+        os.environ["PIPELINE"] = "LREDIS"
+        pipeline = Pipeline()
+        del os.environ["PIPELINE"]
+        pipeline.addSourceTopic("test")
+        assert pipeline.sourceOf("test") is not None
+        pipeline.addDestinationTopic("test")
+        destination = pipeline.destinationOf("test")
+        destination.write(Message({"key": "dummy", "test": "value"}))
+
     def test_pipeline_notset(self):
         with self.assertRaises(PipelineError):
             Pipeline()
